@@ -18,10 +18,10 @@ public:
     ~settingsDialog();
 
 public slots:
-    void ddmmyy();
-    void mmddyy();
-    void yyddmm();
-    void yymmdd();
+    void ddmmyyyy();
+    void mmddyyyy();
+    void yyyyddmm();
+    void yyyymmdd();
 
     void sepDash();
     void sepSlash();
@@ -30,6 +30,9 @@ public slots:
 private:
     Ui::settingsDialog *ui;
     configReader *settParent;
+
+    void updateRadioBtns();
+    void updateExamples();
 };
 
 #endif // SETTINGSDIALOG_H
